Run the recognizer
==================

The recognizer is runned as a local (Flask) web server. It is started with

.. code:: bash

    $ hwrt serve --help
    usage: hwrt serve [-h] [-n N]

    optional arguments:
      -h, --help  show this help message and exit
      -n N        Show TOP-N results

.. image:: browser-ui.png
    :height: 350px
    :align: center
    :alt: Browser interface